# Changelog

## 2025-05-24 - 5.0.0 - BREAKING CHANGE(core)
Rebrand XInvoice to EInvoice: update package name, class names, imports, and documentation

- Renamed package from '@fin.cx/xinvoice' to '@fin.cx/einvoice' in package.json, repository URLs, and readme
- Renamed main class from XInvoice to EInvoice and updated type interfaces (XInvoiceOptions to EInvoiceOptions)
- Updated all import paths and references throughout the codebase including tests, factories, and plugins
- Added a detailed migration guide in MIGRATION.md and updated changelog with breaking changes
- Improved error handling by introducing specialized error classes and recovery utilities
- Ensured all tests and validation suites now reference EInvoice instead of XInvoice

## [5.0.0] - Unreleased

### BREAKING CHANGES
- Renamed package from `@fin.cx/xinvoice` to `@fin.cx/einvoice`
- Renamed main class from `XInvoice` to `EInvoice`
- Renamed `XInvoiceOptions` interface to `EInvoiceOptions`
- Renamed main file from `classes.xinvoice.ts` to `einvoice.ts`
- Updated all exports and imports to use new naming

### Migration Guide
To migrate from v4.x to v5.x:
1. Update package dependency: `@fin.cx/xinvoice` → `@fin.cx/einvoice`
2. Update imports: `import { XInvoice } from '@fin.cx/xinvoice'` → `import { EInvoice } from '@fin.cx/einvoice'`
3. Update class usage: `new XInvoice()` → `new EInvoice()`
4. Update type references: `XInvoiceOptions` → `EInvoiceOptions`

## 2025-05-24 - 4.3.0 - feat(readme.plan)
Add detailed EInvoice Improvement Plan outlining project rebranding, performance optimizations, enhanced error handling, comprehensive test suite, format conversion, and future enterprise features.

- Introduce rebranding from XInvoice to EInvoice with migration guide and updated documentation.
- Outline architectural improvements and modularization for domain-driven design.
- Detail enhanced error handling with specialized error classes and recovery mechanisms.
- Propose performance optimizations including streaming parsing and caching strategies.
- Set up comprehensive testing including format detection, validation, PDF operations, and conversion.
- Expand format support to include FatturaPA and additional international formats.
- Plan for advanced features such as AI/ML integration, enterprise batch processing, and global standards compliance.

## 2025-04-04 - 4.2.2 - fix(documentation)
Improve readme documentation for better clarity on PDF handling, XML validation and error reporting

- Clarify that PDF extraction now includes multiple fallback strategies and robust error handling
- Update usage examples to include payment options, detailed invoice item specifications and proper PDF embedding procedures
- Enhance description of invoice format detection and validation with detailed error reporting
- Improve overall readme clarity by updating instructions and code snippet examples

## 2025-04-04 - 4.2.1 - fix(release)
No changes detected in project files; project remains in sync.


## 2025-04-04 - 4.2.0 - feat(UBL Encoder & Test Suite)
Implement UBLEncoder and update corpus summary generation; adjust PDF timestamps in test outputs

- Added a new UBLEncoder implementation to support exporting invoices in the UBL format
- Updated encoder factory to return UBLEncoder instead of throwing an error for UBL
- Refactored corpus master test to generate a simplified placeholder summary by removing execSync calls
- Adjusted test/output files to update CreationDate and ModDate timestamps in PDFs
- Revised real asset tests to correctly detect UBL format instead of XRechnung for certain files

## 2025-04-04 - 4.1.7 - fix(ZUGFeRD encoder & dependency)
Update @tsclass/tsclass dependency to ^8.2.0 and fix paymentOptions field in ZUGFeRD encoder for proper description output

- Bump @tsclass/tsclass from ^8.1.1 to ^8.2.0 in package.json
- Replace invoice.paymentOptions.info with invoice.paymentOptions.description in ts/formats/cii/zugferd/zugferd.encoder.ts
- Update PDF metadata timestamps in test output

## 2025-04-04 - 4.1.6 - fix(core)
Improve PDF XML extraction, embedding, and format detection; update loadPdf/exportPdf error handling; add new validator implementations and enhance IPdf metadata.

- Update loadPdf to capture extraction result details including detected format and improve error messaging
- Enhance TextXMLExtractor with a chunked approach using both UTF-8 and Latin-1 decoding for reliable text extraction
- Refactor PDFEmbedder to return a structured PDFEmbedResult with proper filename normalization and robust error handling
- Extend format detection logic by adding quickFormatCheck, isUBLFormat, isXRechnungFormat, isCIIFormat, isZUGFERDV1Format, and FatturaPA checks
- Introduce new validator classes (UBLValidator, XRechnungValidator, FatturaPAValidator) and a generic fallback validator in ValidatorFactory
- Update IPdf interface to include embedded XML metadata (format, filename, description) for better traceability

## 2025-04-03 - 4.1.5 - fix(core)
No uncommitted changes detected in the repository. The project files and functionality remain unchanged.


## 2025-04-03 - 4.1.4 - fix(corpus-tests, format-detection)
Adjust corpus test thresholds and improve XML format detection for invoice documents

- Lower expected success rate in corpus tests (e.g. from 70% to 65%) for correct ZUGFeRD files
- Update test result diffs (e.g. updated success/fail counts in corpus-master-results.json and corpus-summary.md)
- Enhance format detection by checking for namespaced root element names (e.g. ending with ':CrossIndustryInvoice' or ':CrossIndustryDocument')
- Improve decoder factory to fallback to ZUGFeRDV1Decoder or ZUGFeRDDecoder when unknown but XML contains key patterns

## 2025-04-03 - 4.1.3 - fix(core)
Refactor module imports to use the centralized plugins module and update relative paths across the codebase. Also remove the obsolete test file (test/test.other-formats-corpus.ts) and update file metadata in test outputs.

- Updated import statements in modules (e.g., ts/classes.xinvoice.ts, ts/formats/*, and ts/interfaces/common.ts) to import DOMParser, xpath, and other dependencies from './plugins.js' instead of directly from 'xmldom' and 'xpath'.
- Adjusted import paths in test asset files such as test/assets/letter/letter1.ts.
- Removed the obsolete test file test/test.other-formats-corpus.ts.
- Test output files now show updated CreationDate/ModDate metadata.

## 2025-04-03 - 4.1.2 - fix(readme)
Update readme documentation: enhance feature summary, update installation instructions and usage examples, remove obsolete config details, and better clarify supported invoice formats.

- Rewrote introduction to emphasize comprehensive feature support (multi-format, PDF handling, validation, modular architecture)
- Updated installation instructions with commands for pnpm, npm, and yarn
- Removed outdated TypeScript configuration and extended usage sections
- Clarified supported invoice standards and provided a concise summary of format details

## 2025-04-03 - 4.1.1 - fix(zugferd)
Refactor Zugferd decoders to properly extract house numbers from street names and remove unused imports; update readme hints with additional TInvoice reference and refresh PDF metadata timestamps.

- Use regex in zugferd.decoder.ts and zugferd.v1.decoder.ts to split the street name and extract the house number.
- Remove the unnecessary 'general' import from '@tsclass/tsclass' in zugferd decoder files.
- Update readme.hints.md with a reference to the TInvoice type from @tsclass/tsclass.
- Update the CreationDate and ModDate in the embedded PDF asset to new timestamps.

## 2025-04-03 - 4.1.0 - feat(ZUGFERD)
Add dedicated ZUGFERD v1/v2 support and refine invoice format detection logic

- Improve FormatDetector to differentiate between Factur-X, ZUGFERD v1, and ZUGFERD v2 formats
- Introduce dedicated ZUGFERD decoder, encoder, and validator implementations
- Update factories to use ZUGFERD-specific classes rather than reusing FacturX implementations
- Enhance PDF XML extraction by consolidating multiple extractor strategies
- Update module exports and documentation hints for improved testing and integration

## 2025-03-20 - 3.0.1 - fix(test/pdf-export)
Improve PDF export tests with detailed logging and enhanced embedded file structure verification.

- Log original PDF size and compute size increases per export format
- Print a table of format-specific PDF size details
- Verify the PDF catalog contains the 'Names' dictionary, 'EmbeddedFiles' entry, and a valid 'Names' array
- Ensure type safety for export format parameters

## 2025-03-20 - 3.0.0 - BREAKING CHANGE(XInvoice)
Refactor XInvoice API for XML handling and PDF export by replacing deprecated methods (addXmlString and getParsedXmlData) with fromXml and loadXml, and by introducing a new ExportFormat type for type-safe export. Update tests accordingly.

- Removed usage of addXmlString and getParsedXmlData in favor of XInvoice.fromXml and loadXml for XML processing.
- Added ExportFormat type and enforced type-safety in exportXml and exportPdf methods.
- Updated test files to adapt to the new API, ensuring proper error handling and API consistency.
- Revised expectations in tests to check for new methods (loadXml, validate, exportXml, exportPdf) and properties.

## 2025-03-20 - 2.0.0 - BREAKING CHANGE(core)
Refactor contact and PDF handling across the library by replacing IContact with TContact and updating PDF processing to use a structured IPdf object. These changes ensure that empty contact objects include registration details, founded/closed dates, and status, and that PDF loading/exporting uniformly wraps buffers in a proper object.

- Updated createEmptyContact (renamed in documentation to reflect TContact) to return a complete TContact object with registrationDetails, foundedDate, closedDate, and status.
- Modified loadPdf and exportPdf in XInvoice to wrap PDF buffers in an IPdf object with name, id, and metadata instead of using a raw Uint8Array.
- Replaced IContact with TContact in FacturXEncoder, FacturXDecoder, and XInvoiceDecoder to standardize contact structure.
- Aligned address and contact data across decoders and encoders for consistency.

## 2025-03-17 - 1.3.3 - fix(commitinfo)
Synchronize commit info version with package.json version

- Updated ts/00_commitinfo_data.ts from version '1.3.1' to '1.3.2' to match package.json

## 2025-03-17 - 1.3.1 - fix(documentation)
Update readme to enhance installation instructions and expand feature documentation for Factur-X/ZUGFeRD, UBL, and FatturaPA support, including details on circular encoding/decoding.

- Added pnpm installation instructions
- Expanded description of supported European e-invoicing standards
- Clarified usage of FacturXEncoder and ZUGFeRDXmlDecoder for XML encoding/decoding
- Included detailed feature summary for PDF integration, encoding/decoding, and format detection

## 2025-03-17 - 1.3.0 - feat(encoder)
Rename encoder class from ZugferdXmlEncoder to FacturXEncoder to better reflect Factur-X compliance. All related imports, exports, and tests have been updated while maintaining backward compatibility.

- Renamed the encoder class to FacturXEncoder and added an alias for backward compatibility (FacturXEncoder as ZugferdXmlEncoder)
- Updated test files and TS index exports to reference the new class name
- Improved XML creation formatting and documentation within the encoder module

## 2025-03-17 - 1.2.0 - feat(core)
Improve XML processing and error handling for PDF invoice attachments

- Update dependency versions and lock file references in package.json
- Add XML declaration validation in addXmlString to prevent invalid XML input
- Enhance XML extraction, format detection, and parsing logic in XInvoice and ZUGFeRDXmlDecoder
- Extend test coverage with additional validations for XML, letter data, and error handling scenarios

## 2025-01-01 - 1.1.2 - fix(core)
Fix file import paths and remove markdown syntax from README

- Corrected import paths for getInvoice utility
- Removed markdown syntax from README
- Fixed function parameter usage in encoder class

## 2024-12-31 - 1.1.1 - fix(documentation)
Updated documentation to reflect accurate module description and usage guidance

- Corrected description in package.json to better reflect the module's functionalities.
- Enhanced README with detailed setup and usage instructions.
- Included examples for embedding XML into PDFs and parsing XML data.

## 2024-12-30 - 1.1.0 - feat(core)
Add EInvoiceCreator class for generating ZUGFeRD/Factur-X XML

- Introduced EInvoiceCreator class to convert invoice data into ZUGFeRD/Factur-X XML.
- Updated development dependencies to enhance TypeScript support.
- Added SmartXML and TSClass plugins for XML handling and business logic.

## 2024-07-02 - 1.0.6 - fix(core)
Project files committed with initial structure and class implementation

- Added package.json with project dependencies and scripts
- Included guide in readme.md on how to install and use the module
- Implemented ts/plugins.ts for exporting native Node.js and third-party modules
- Defined interfaces in ts/interfaces.ts to represent the structure of invoices
- Created ts/index.ts to export interfaces and classes
- Implemented XInvoice class in ts/classes.xinvoice.ts with methods for embedding and extracting XML from PDFs
- Added test/test.ts for basic testing of the embed XML functionality

## 2024-04-22 - 1.0.3 to 1.0.5 - core
Minor updates and bug fixes.

- fix: core update in versions 1.0.3 and 1.0.4