/**
 * Centralized imports for all external npm modules
 * This file serves as a single point of import for all external dependencies
 * to make the codebase more maintainable and follow the DRY principle.
 */

// Node.js built-in modules
import * as fs from 'fs/promises';
import * as path from 'path';
import * as crypto from 'crypto';

// PDF-related imports
import { 
  PDFDocument, 
  PDFDict, 
  PDFName, 
  PDFRawStream, 
  PDFArray, 
  PDFString,
  AFRelationship
} from 'pdf-lib';

// XML-related imports
import { DOMParser, XMLSerializer } from 'xmldom';
import * as xpath from 'xpath';

// Compression-related imports
import * as pako from 'pako';

// Business model imports
import { business, finance, general } from '@tsclass/tsclass';

// Re-export all imports
export {
  // Node.js built-in modules
  fs,
  path,
  crypto,
  
  // PDF-lib exports
  PDFDocument,
  PDFDict,
  PDFName,
  PDFRawStream,
  PDFArray,
  PDFString,
  AFRelationship,
  
  // XML-related exports
  DOMParser,
  XMLSerializer,
  xpath,
  
  // Compression-related exports
  pako,
  
  // Business model exports
  business,
  finance,
  general
};
